@@ -1,3 +1,7 @@
+from __future__ import unicode_literals
+
+import copy
+
 from .datastructures import FilteredImage, SizedImage
 
 
@@ -9,6 +13,10 @@ class InvalidSizedImageSubclass(Exception):
     pass
 
 
+class InvalidFilteredImageSubclass(Exception):
+    pass
+
+
 class NotRegistered(Exception):
     pass
 
@@ -42,6 +50,14 @@ class VersatileImageFieldRegistry(object):
         'fileno',
         'filters',
         'flush',
+        'get_filtered_root_folder',
+        'get_sized_root_folder',
+        'get_filtered_sized_root_folder',
+        'delete_matching_files_from_storage',
+        'delete_filtered_images',
+        'delete_sized_images',
+        'delete_filtered_sized_images',
+        'delete_all_created_images',
         'height',
         'instance',
         'isatty',
@@ -77,10 +93,12 @@ class VersatileImageFieldRegistry(object):
 
     def register_sizer(self, attr_name, sizedimage_cls):
         """
-        Registers a new SizedImage subclass (`sizedimage_cls`) to be used
+        Register a new SizedImage subclass (`sizedimage_cls`) to be used
         via the attribute (`attr_name`)
         """
-        if attr_name.startswith('_') or attr_name in self.unallowed_sizer_names:
+        if attr_name.startswith(
+            '_'
+        ) or attr_name in self.unallowed_sizer_names:
             raise UnallowedSizerName(
                 "`%s` is an unallowed Sizer name. Sizer names cannot begin "
                 "with an underscore or be named any of the "
@@ -100,16 +118,16 @@ class VersatileImageFieldRegistry(object):
 
         if attr_name in self._sizedimage_registry:
             raise AlreadyRegistered(
-                'A SizedImage class is already registered to the `%s` attribute. '
-                'If you would like to override this attribute, use the '
-                'unregister method' % attr_name
+                'A SizedImage class is already registered to the `%s` '
+                'attribute. If you would like to override this attribute, '
+                'use the unregister method' % attr_name
             )
         else:
             self._sizedimage_registry[attr_name] = sizedimage_cls
 
     def unregister_sizer(self, attr_name):
         """
-        Unregisters the SizedImage subclass currently assigned to `attr_name`.
+        Unregister the SizedImage subclass currently assigned to `attr_name`.
 
         If a SizedImage subclass isn't already registered to `attr_name`
         NotRegistered will raise.
@@ -123,7 +141,7 @@ class VersatileImageFieldRegistry(object):
 
     def register_filter(self, attr_name, filterimage_cls):
         """
-        Registers a new FilteredImage subclass (`filterimage_cls`) to be used
+        Register a new FilteredImage subclass (`filterimage_cls`) to be used
         via the attribute (filters.`attr_name`)
         """
         if attr_name.startswith('_'):
@@ -132,22 +150,23 @@ class VersatileImageFieldRegistry(object):
                 'with an underscore.' % attr_name
             )
         if not issubclass(filterimage_cls, FilteredImage):
-            raise InvalidSizedImageSubclass(
-                'Only subclasses of FilteredImage may be registered as filters'
-                'with VersatileImageFieldRegistry')
+            raise InvalidFilteredImageSubclass(
+                'Only subclasses of FilteredImage may be registered as '
+                'filters with VersatileImageFieldRegistry'
+            )
 
         if attr_name in self._filter_registry:
             raise AlreadyRegistered(
-                'A ProcessedImageMixIn class is already registered to the `%s` '
-                'attribute. If you would like to override this attribute, use '
-                'the unregister method' % attr_name
+                'A ProcessedImageMixIn class is already registered to the `%s`'
+                ' attribute. If you would like to override this attribute, '
+                'use the unregister method' % attr_name
             )
         else:
             self._filter_registry[attr_name] = filterimage_cls
 
     def unregister_filter(self, attr_name):
         """
-        Unregisters the FilteredImage subclass currently assigned to
+        Unregister the FilteredImage subclass currently assigned to
         `attr_name`.
 
         If a FilteredImage subclass isn't already registered to filters.
@@ -165,22 +184,16 @@ versatileimagefield_registry = VersatileImageFieldRegistry()
 
 def autodiscover():
     """
-    Auto-discover INSTALLED_APPS sizedimage.py modules and fail silently when
-    not present. This forces an import on them to register any versatileimagefield
-    bits they may want.
-
-    This is a near 1-to-1 copy of how django's admin application registers
-    models.
+    Iterate over django.apps.get_app_configs() and discover
+    versatileimagefield.py modules.
     """
-
-    import copy
-    from django.conf import settings
-    from django.utils.importlib import import_module
+    from importlib import import_module
+    from django.apps import apps
     from django.utils.module_loading import module_has_submodule
 
-    for app in settings.INSTALLED_APPS:
-        mod = import_module(app)
-        # Attempt to import the app's sizedimage module.
+    for app_config in apps.get_app_configs():
+        # Attempt to import the app's module.
+
         try:
             before_import_sizedimage_registry = copy.copy(
                 versatileimagefield_registry._sizedimage_registry
@@ -188,17 +201,19 @@ def autodiscover():
             before_import_filter_registry = copy.copy(
                 versatileimagefield_registry._filter_registry
             )
-            import_module('%s.versatileimagefield' % app)
+            import_module('%s.versatileimagefield' % app_config.name)
         except:
-            # Reset the versatileimagefield_registry to the state before the last
-            # import as this import will have to reoccur on the next request
-            # and this could raise NotRegistered and AlreadyRegistered
+            # Reset the versatileimagefield_registry to the state before the
+            # last import as this import will have to reoccur on the next
+            # request and this could raise NotRegistered and AlreadyRegistered
             # exceptions (see django ticket #8245).
-            versatileimagefield_registry._sizedimage_registry = before_import_sizedimage_registry
-            versatileimagefield_registry._filter_registry = before_import_filter_registry
+            versatileimagefield_registry._sizedimage_registry = \
+                before_import_sizedimage_registry
+            versatileimagefield_registry._filter_registry = \
+                before_import_filter_registry
 
             # Decide whether to bubble up this error. If the app just
-            # doesn't have a sizedimage module, we can ignore the error
+            # doesn't have the module in question, we can ignore the error
             # attempting to import it, otherwise we want it to bubble up.
-            if module_has_submodule(mod, 'versatileimagefield'):
+            if module_has_submodule(app_config.module, 'versatileimagefield'):
                 raise
