@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from django.forms.widgets import (
     CheckboxInput, ClearableFileInput,
     HiddenInput, MultiWidget, Select
@@ -23,18 +25,18 @@ CENTERPOINT_CHOICES = (
 class ClearableFileInputWithImagePreview(ClearableFileInput):
     ppoi_label = ugettext_lazy('Primary Point of Interest')
     template_with_clear = (
+        '<div class="sizedimage-mod clear">'
         '%(clear)s <label class="versatileimagefield-label" '
         'for="%(clear_checkbox_id)s">'
-        '%(clear_checkbox_label)s</label>'
+        '%(clear_checkbox_label)s: </label>'
+        '</div>'
     )
     template_with_initial_and_imagepreview = """
     <div class="sizedimage-mod initial">
         <label class="versatileimagefield-label">%(initial_text)s</label>
         %(initial)s
     </div>
-    <div class="sizedimage-mod clear">
-        %(clear_template)s
-    </div>
+    %(clear_template)s
     <div class="sizedimage-mod preview">
         <label class="versatileimagefield-label">%(ppoi_label)s</label>
         <div class="image-wrap outer">
@@ -52,15 +54,6 @@ class ClearableFileInputWithImagePreview(ClearableFileInput):
         %(input)s
     </div>"""
 
-    def __init__(self, attrs=None, image_preview_template=None,
-                 clear_checkbox_template=None):
-        if image_preview_template:
-            self.template_with_initial_and_imagepreview = \
-                image_preview_template
-        if clear_checkbox_template:
-            self.template_with_clear = clear_checkbox_template
-        super(ClearableFileInputWithImagePreview, self).__init__(attrs)
-
     def get_hidden_field_id(self, name):
         i = name.rindex('_')
         return "id_%s_%d" % (name[:i], int(name[i + 1:]) + 1)
@@ -80,9 +73,6 @@ class ClearableFileInputWithImagePreview(ClearableFileInput):
     def get_point_stage_id(self, name):
         return name + '_point-stage'
 
-    def get_point_id(self, name):
-        return name + '_point-id'
-
     def image_preview(self, name, value):
         """
         Given the name of the image preview tag, return the HTML id for it.
@@ -118,22 +108,20 @@ class ClearableFileInputWithImagePreview(ClearableFileInput):
             substitutions['initial'] = format_html('<a href="{0}">{1}</a>',
                                                    value.url,
                                                    force_text(value))
-            if value.field.ppoi_field:
-                template = self.template_with_initial_and_imagepreview
-                point_stage_id = self.get_point_stage_id(name)
-                ppoi_id = self.get_ppoi_id(name)
-                substitutions['point_stage_id'] = point_stage_id
-                substitutions['ppoi_id'] = ppoi_id
-                substitutions['image_preview_id'] = self.image_preview_id(name)
-                image_preview = self.image_preview(
-                    name,
-                    value
-                )
-                substitutions['image_preview'] = image_preview
-            else:
-                template = self.template_with_initial
+            substitutions['initial_url'] = value.url
+            template = self.template_with_initial_and_imagepreview
+            point_stage_id = self.get_point_stage_id(name)
+            ppoi_id = self.get_ppoi_id(name)
+            substitutions['point_stage_id'] = point_stage_id
+            substitutions['ppoi_id'] = ppoi_id
+            substitutions['image_preview_id'] = self.image_preview_id(name)
+            image_preview = self.image_preview(
+                name,
+                value
+            )
+            substitutions['image_preview'] = image_preview
 
-            if not self.is_required:
+            if value.field.blank:
                 checkbox_name = self.clear_checkbox_name(name)
                 checkbox_id = self.clear_checkbox_id(checkbox_name)
                 substitutions['clear_checkbox_name'] = conditional_escape(
@@ -155,12 +143,13 @@ class ClearableFileInputWithImagePreview(ClearableFileInput):
 class SizedImageCenterpointWidgetMixIn(object):
 
     def decompress(self, value):
+        to_return = [None, None]
         if value:
-            return [
+            to_return = [
                 value,
-                u'x'.join(unicode(num) for num in value.ppoi)
+                'x'.join(str(num) for num in value.ppoi)
             ]
-        return [None, None]
+        return to_return
 
 
 class VersatileImagePPOISelectWidget(SizedImageCenterpointWidgetMixIn,
@@ -186,8 +175,6 @@ class VersatileImagePPOIClickWidget(SizedImageCenterpointWidgetMixIn,
         widgets = (
             ClearableFileInputWithImagePreview(
                 attrs={'class': 'file-chooser'},
-                image_preview_template=self.image_preview_template or None,
-                clear_checkbox_template=self.clear_checkbox_template or None
             ),
             HiddenInput(
                 attrs={'class': 'ppoi-input'}
@@ -199,9 +186,7 @@ class VersatileImagePPOIClickWidget(SizedImageCenterpointWidgetMixIn,
         css = {
             'all': ('versatileimagefield/css/versatileimagefield.css',),
         }
-        js = (
-            'versatileimagefield/js/versatileimagefield.js',
-        )
+        js = ('versatileimagefield/js/versatileimagefield.js',)
 
     def render(self, name, value, attrs=None):
         rendered = super(VersatileImagePPOIClickWidget, self).render(
@@ -219,15 +204,13 @@ class SizedImageCenterpointClickDjangoAdminWidget(
 
     class Media:
         css = {
-            'all': (
-                'versatileimagefield/css/versatileimagefield-djangoadmin.css',
-            ),
+            'all': ('versatileimagefield/css/versatileimagefield-djangoadmin.css',),
         }
 
 
 class SizedImageCenterpointClickBootstrap3Widget(
         VersatileImagePPOIClickWidget):
-    image_preview_template = """
+    template_with_initial_and_imagepreview = """
     <div class="form-group">
         <label>%(initial_text)s</label>
         %(initial)s
@@ -251,8 +234,7 @@ class SizedImageCenterpointClickBootstrap3Widget(
         <label class="versatileimagefield-label">%(input_text)s</label>
         %(input)s
     </div>"""
-
-    clear_checkbox_template = (
+    template_with_clear = (
         '<label for="%(clear_checkbox_id)s"'
         'class="checkbox-inline">%(clear)s %(clear_checkbox_label)s'
         '</label>'
@@ -260,7 +242,5 @@ class SizedImageCenterpointClickBootstrap3Widget(
 
     class Media:
         css = {
-            'all': (
-                'versatileimagefield/css/versatileimagefield-bootstrap3.css',
-            ),
+            'all': ('versatileimagefield/css/versatileimagefield-bootstrap3.css',),
         }
